@@ -10,6 +10,8 @@ import matplotlib.pyplot as plt
 import matplotlib as mpl
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 
+from gpflow import set_trainable
+
 from IPython.display import display, HTML
 from tabulate import tabulate
 
@@ -19,7 +21,8 @@ logging.getLogger('tensorflow').setLevel(logging.ERROR)
 
 tf.autograph.set_verbosity(0) # TODO: remove and fix problem
 
-gpflow.config.set_default_positive_minimum(1e-6)
+# gpflow.config.set_default_positive_minimum(1e-6)
+eps = 1e-20
 
 logger = logging.getLogger('mogptk')
 
@@ -301,8 +304,7 @@ class model:
 
         for i, v in np.ndenumerate(val):
             if v < gpflow.config.default_positive_minimum():
-                val[i] = gpflow.config.default_positive_minimum()
-
+                val[i] = gpflow.config.default_positive_minimum() + eps
         kern[key].assign(val)
 
     def set_likelihood_parameter(self, key, val):
@@ -330,7 +332,7 @@ class model:
 
         for i, v in np.ndenumerate(val):
             if v < gpflow.config.default_positive_minimum():
-                val[i] = gpflow.config.default_positive_minimum()
+                val[i] = gpflow.config.default_positive_minimum() + eps
 
         likelihood[key].assign(val)
 
@@ -354,11 +356,11 @@ class model:
                 kernel = self.model.kernel.kernels[kernel_i]
                 for param_name, param_val in kernel.__dict__.items():
                     if param_name == key and isinstance(param_val, gpflow.base.Parameter):
-                        getattr(self.model.kernel.kernels[kernel_i], param_name).trainable = False
+                        set_trainable(getattr(self.model.kernel.kernels[kernel_i], param_name), False)
         else:
             for param_name, param_val in self.model.kernel.__dict__.items():
                 if param_name == key and isinstance(param_val, gpflow.base.Parameter):
-                    getattr(self.model.kernel, param_name).trainable = False
+                    set_trainable(getattr(self.model.kernel, param_name), False)
 
     def unfix_parameter(self, q, key):
         """
@@ -380,11 +382,11 @@ class model:
                 kernel = self.model.kernel.kernels[kernel_i]
                 for param_name, param_val in kernel.__dict__.items():
                     if param_name == key and isinstance(param_val, gpflow.base.Parameter):
-                        getattr(self.model.kernel.kernels[kernel_i], param_name).trainable = True
+                        set_trainable(getattr(self.model.kernel.kernels[kernel_i], param_name), False)
         else:
             for param_name, param_val in self.model.kernel.__dict__.items():
                 if param_name == key and isinstance(param_val, gpflow.base.Parameter):
-                    getattr(self.model.kernel, param_name).trainable = True
+                    set_trainable(getattr(self.model.kernel, param_name), True)
 
     def save_parameters(self, filename):
         """
